@@ -3,6 +3,8 @@ from .despike import *
 from .rotate_wind3D import rotate_wind
 from .correlate_delay import remove_lag
 from .spectrum_analysis import Spec
+from . import eddyqc
+from .eddyqc import *
 
-
-__all__ = ["Raw", "despikeVM", "rotate_wind", "remove_lag", "Spec"]
\ No newline at end of file
+__all__ = ["Raw", "despikeVM", "rotate_wind", "remove_lag", "Spec"]
+__all__ += eddyqc.__all__
\ No newline at end of file
